@@ -7,7 +7,7 @@ from .base import Base
 from .utils import check, dataset
 class DatasetManager(Base):
 
-    def upload_file(self, directory_id=None, file_path=None, description="", lineage=None):
+    def upload_file(self, directory_id=None, file_path=None, file_name=None, description="", lineage=None, replace=None):
         """_summary_
 
         Args:
@@ -37,8 +37,12 @@ class DatasetManager(Base):
         if _res.status_code == 404:
             raise Exception(f"directory {directory_id} not found or your dose not has permission to access directory")
         
-        f_name = os.path.basename(file_path)
-        replace = self._check_fileExists(directory_id, f_name)
+        if file_name:
+            f_name = file_name
+        else:
+            f_name = os.path.basename(file_path)
+            
+        replace = self._check_fileExists(directory_id, f_name) if replace is None else replace
         
         if description == "":
             description = f"file {f_name}"
