@@ -1,3 +1,5 @@
+import requests
+import time
 from .requests import check_http_status_code
 
 def check_lists_int(data=None, dataName="data"):
@@ -19,4 +21,15 @@ def check_type(variable, variableName, dtype, child=None):
     if child is not None:
         for elm in variable:
             if type(elm) != child:
-                raise Exception(f"{variableName} expect [{child}, {child}, ... {child}] but has {elm}({type(elm)})")
\ No newline at end of file
+                raise Exception(f"{variableName} expect [{child}, {child}, ... {child}] but has {elm}({type(elm)})")
+
+def check_file_already(discovery_api, file_id, header):
+    _is_pass = False
+    for _ in range(5):
+        _res = requests.get(f"{discovery_api}/file/{file_id}/", headers=header)
+        if _res.status_code != 200:
+            time.sleep(2)
+        else:
+            _is_pass = True
+            break
+    return _is_pass
\ No newline at end of file
